@@ -1,11 +1,13 @@
 #!/usr/bin/env bash
 
-git init
+#git init
 # shellcheck disable=SC2035
 git add *
 git commit -m "init"
 
-git remote add origin git@github.com:yuanjie-ai/llm4gpt.git
-git branch -M master
+#git remote add origin git@github.com:yuanjie-ai/llm4gpt.git
+#git branch -M master
+
+git pull
 git push -u origin master
 # git remote remove origin
